/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface UpcloudProviderConfig {
    /**
    * Password for UpCloud API user. Can also be configured using the `UPCLOUD_PASSWORD` environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs#password UpcloudProvider#password}
    */
    readonly password?: string;
    /**
    * Maximum number of retries
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs#retry_max UpcloudProvider#retry_max}
    */
    readonly retryMax?: number;
    /**
    * Maximum time to wait between retries
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs#retry_wait_max_sec UpcloudProvider#retry_wait_max_sec}
    */
    readonly retryWaitMaxSec?: number;
    /**
    * Minimum time to wait between retries
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs#retry_wait_min_sec UpcloudProvider#retry_wait_min_sec}
    */
    readonly retryWaitMinSec?: number;
    /**
    * UpCloud username with API access. Can also be configured using the `UPCLOUD_USERNAME` environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs#username UpcloudProvider#username}
    */
    readonly username?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs#alias UpcloudProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs upcloud}
*/
export declare class UpcloudProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "upcloud";
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/2.12.0/docs upcloud} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options UpcloudProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: UpcloudProviderConfig);
    private _password?;
    get password(): string | undefined;
    set password(value: string | undefined);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _retryMax?;
    get retryMax(): number | undefined;
    set retryMax(value: number | undefined);
    resetRetryMax(): void;
    get retryMaxInput(): number | undefined;
    private _retryWaitMaxSec?;
    get retryWaitMaxSec(): number | undefined;
    set retryWaitMaxSec(value: number | undefined);
    resetRetryWaitMaxSec(): void;
    get retryWaitMaxSecInput(): number | undefined;
    private _retryWaitMinSec?;
    get retryWaitMinSec(): number | undefined;
    set retryWaitMinSec(value: number | undefined);
    resetRetryWaitMinSec(): void;
    get retryWaitMinSecInput(): number | undefined;
    private _username?;
    get username(): string | undefined;
    set username(value: string | undefined);
    resetUsername(): void;
    get usernameInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
